==> haskell-xss-sanitize-0.3.7.2-126.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xss-sanitize
version:              0.3.7.2
visibility:           public
id:                   xss-sanitize-0.3.7.2-59B4wNerfIq6S99jIilTRX
key:                  xss-sanitize-0.3.7.2-59B4wNerfIq6S99jIilTRX
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  2fc448d8778f16346d7092df5c215e70
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7.2-59B4wNerfIq6S99jIilTRX
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    containers-0.6.7 css-text-0.1.3.0-BWAcyWZISYcHszluw9BWW5
    network-uri-2.6.4.2-69jfmnohyG88ZQKNy7a5sS
    tagsoup-0.14.8-7NiSWLVr0pz5UlKWFZNHUS text-2.0.2
    utf8-string-1.0.2-6mVuGO0K0TVHYD6zuQNk2y

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xss-sanitize-0.3.7.2-127-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-xss-sanitize.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xss-sanitize
version:              0.3.7.2
visibility:           public
id:                   xss-sanitize-0.3.7.2-8cNHDGVpLwFLDuj2Azhm7R
key:                  xss-sanitize-0.3.7.2-8cNHDGVpLwFLDuj2Azhm7R
license:              BSD-2-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Greg Weber <greg@gregweber.info>
stability:            Stable
homepage:             https://github.com/yesodweb/haskell-xss-sanitize#readme
synopsis:             sanitize untrusted HTML to prevent XSS attacks
description:
    run untrusted HTML through Text.HTML.SanitizeXSS.sanitizeXSS to prevent XSS attacks. see README.md <http://github.com/yesodweb/haskell-xss-sanitize> for more details

category:             Web
abi:                  58736f1d11d3099acaa07496e4e58bd1
exposed:              True
exposed-modules:      Text.HTML.SanitizeXSS
hidden-modules:       Text.HTML.SanitizeXSS.Css Paths_xss_sanitize
import-dirs:          /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xss-sanitize-0.3.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xss-sanitize
hs-libraries:         HSxss-sanitize-0.3.7.2-8cNHDGVpLwFLDuj2Azhm7R
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    containers-0.6.7 css-text-0.1.3.0-EabfuOGZPIdI0loquvBori
    network-uri-2.6.4.2-ImBkmHhWmdwGJdqs22FerI
    tagsoup-0.14.8-DBaP5fMg0izLpBRp0VL2HR text-2.0.2
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:
    /usr/share/doc/haskell-xss-sanitize/html/xss-sanitize.haddock

haddock-html:         /usr/share/doc/haskell-xss-sanitize/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
